flickrsmartsync - Sync/backup your photos to flickr easily
------------------
flickrsmartsync is a tool you can use to easily sync up or down your
photos in a drive/folder to flickr since now it has a free 1TB storage
you can probably sync all your photo collection.


Installation
---------------
You need python-pip installed

    pip install flickrsmartsync


Example Usage::

    # start uploading all photos under that folder
    $ flickrsmartsync

    # start downloading all photos on flickr to that folder
    $ flickrsmartsync --download .
    
    # start downloading all paths starting with that path
    $ flickrsmartsync --download 2008/2008-01-01

    # for direct python access
    $ python flickrsmartsync


More info
--------------
[Backup/Sync Your Photos to flickr - Blog Post](http://blog.altlimit.com/2013/05/backupsync-your-photos-to-flickr-script.html)

[Download the egg file](https://pypi.python.org/pypi/flickrsmartsync)
